# -*- coding: utf-8 -*-

class AcropolisObjectTypeEnum(object):

    """Implementation of the 'acropolisObjectType' enum.

    TODO: type enum description here.

    Attributes:
        KPRISMCENTRAL: TODO: type description here.
        KSTANDALONECLUSTER: TODO: type description here.
        KOTHERHYPERVISORCLUSTER: TODO: type description here.
        KCLUSTER: TODO: type description here.
        KHOST: TODO: type description here.
        KVIRTUALMACHINE: TODO: type description here.
        KNETWORK: TODO: type description here.
        KSTORAGECONTAINER: TODO: type description here.

    """

    KPRISMCENTRAL = 'kPrismCentral'

    KSTANDALONECLUSTER = 'kStandaloneCluster'

    KOTHERHYPERVISORCLUSTER = 'kOtherHypervisorCluster'

    KCLUSTER = 'kCluster'

    KHOST = 'kHost'

    KVIRTUALMACHINE = 'kVirtualMachine'

    KNETWORK = 'kNetwork'

    KSTORAGECONTAINER = 'kStorageContainer'
